---
name: Bug report
about: Create a report to help us improve
title: "[BUG]"
labels: bug
assignees: ''

---

**Describe the bug**

A clear and concise description of what the bug is.

**To Reproduce**

Steps to reproduce the behavior:
1. Go to '...'
2. Click on '....'
3. Scroll down to '....'
4. See error

**Expected behavior**

A clear and concise description of what you expected to happen.

**Screenshots**

If applicable, add screenshots to help explain your problem.

**System information**

Please complete the following information
- Operating system: [e.g. Manjaro/Windows 10]
- Version [e.g. 1.6.2]
- Installation method [e.g. pip/msi/AppImage]
- Python version (if installed through `pip` or your package manager)

**Additional context**

Add any other context about the problem here.

**Error message**

You can find logs in these locations

| OS      | Path                                                     |
|---------|----------------------------------------------------------|
| Windows | `C:\Users\<username>\AppData\Local\Rare\Rare\cache\logs` |
| Linux   | `/home/<username>/.cache/Rare/Rare/logs`                 |
| masOS   | `/Users/<username>/Library/Caches/Rare/Rare/logs`        |
